// ==============================================================
//                 ORBITER MODULE: BELL222
//                  Part of the ORBITER SDK
//          Copyright (C) 2002-2004 Martin Schweiger
//                   All rights reserved
//
// BELL222.cpp
// Control module for BELL222 vessel class
//

// ==============================================================
#define ORBITER_MODULE
#include "orbitersdk.h"
#include "BELL222.h"
#include "UCGOCargoSDK.h" //UCGO 2.0 copy past this line
#include "OrbiterSoundSDK40.h"
VISHANDLE MainExternalMeshVisual = 0;


//vertical lift component (wings and body)
void VLiftCoeff(VESSEL *v,double aoa,double M,double Re,void *context,double *cl,double *cm,double *cd)

{
 int i;
 const int nabsc=33;
 static const double AOA[nabsc]={-180*RAD,-165*RAD,-150*RAD,-135*RAD,-120*RAD,-105*RAD,-90*RAD,-75*RAD,-60*RAD,-45*RAD,-30*RAD, -25*RAD , -20*RAD , -15*RAD , -10*RAD , -5*RAD , 0*RAD , 5*RAD , 10*RAD , 15*RAD , 20*RAD , 25*RAD,  30*RAD, 60*RAD, 90*RAD, 120*RAD, 150*RAD, 165*RAD, 180*RAD };

 static const double CL[nabsc] ={       0,      0,   -0.4,      0,    0.7,     1,   0.8,     0,      0};
 static const double CM[nabsc] ={ -0.015 , -0.008 , -0.018 , -0.027 , -0.030 , -0.033 , -0.031, -0.025, -0.017, -0.011, -0.005 , -0.00  , 0.03  , 0.003  , 0.001  , -0.00 , -0.00 , -0.001, -0.004, -0.008 , -0.011 , -0.014,  -0.018,-0.030 , -0.031,-0.017  , -0.005 , -0.003 , -0.015 };   	

 for(i=0;i<nabsc-1 && AOA[i+1]<aoa;i++);
 double f=(aoa-AOA[i])/(AOA[i+1]-AOA[i]);
 *cl=CL[i]+(CL[i+1]-CL[i])*f;  //aoa-dependent lift coefficient
 *cm=CM[i]+(CM[i+1]-CM[i])*f;  //aoa-dependent moment coefficient
 double saoa=sin(aoa);
 double pd=0.015+0.4*saoa*saoa;  //profile drag
 *cd=pd+oapiGetInducedDrag(*cl,1.5,0.7)+oapiGetWaveDrag(M,0.75,1.0,1.1,0.04);
 //profile drag+(lift-)induced drag+transonic/supersonic wave (compressibility) drag
}
//############################################################################//

//horizontal lift component (vertical stabilisers and body)
void HLiftCoeff(VESSEL *v,double betta,double M,double Re,void *context,double *cl,double *cm,double *cd)
{
 int i;
 const int nabsc=8;
 static const double BETA[nabsc]={-180*RAD,-135*RAD,-90*RAD,-45*RAD,45*RAD,90*RAD,135*RAD,180*RAD};
 static const double CL[nabsc]  ={       0,    +0.3,      0,   -0.3,  +0.3,     0,   -0.3,      0};
 for(i=0;i<nabsc-1 && BETA[i+1]<betta;i++);
 *cl=CL[i]+(CL[i+1]-CL[i])*(betta-BETA[i])/(BETA[i+1]-BETA[i]);
 *cm=0.0;
 *cd=0.015+oapiGetInducedDrag(*cl,1.5,0.6)+oapiGetWaveDrag(M,0.75,1.0,1.1,0.04);
}







char *BELL222::SendHudMessage()
{
dHudMessageDelay=15;
return cUmmuHudDisplay;
}

void BELL222::SetUMMUAirlockPos(void)
{
int AirlockStatus=Crew.GetAirlockDoorState();
	Crew.SetActiveDockForTransfer(iActiveDockNumber);
	switch(iActiveDockNumber)
	{
		
	case 0:	//LEFT
Crew.DefineAirLockShape(AirlockStatus,.9,2.5,-4,3,4.6,6);			
		Crew.SetMembersPosRotOnEVA(_V(-1.88 ,-1.2778,5),_V(0,0,0));	
	
			doorselected=0;
		break;
	case 1:	//LEFT
Crew.DefineAirLockShape(AirlockStatus,0,3,-6,6,4.6,6);			
		Crew.SetMembersPosRotOnEVA(_V(1.88 ,-1.2778,5),_V(0,0,0));	
	
			doorselected=1;
		break;



	case 2:	//LEFT REAR
		Crew.DefineAirLockShape(AirlockStatus,-1,3,-6,6,3,4.5);		
	Crew.SetMembersPosRotOnEVA(_V(-1.5,-1.2778,3.7),_V(0,3,0));
	doorselected=2;
		break;
		
	
	case 3:	//RIGHT REAR
		Crew.DefineAirLockShape(AirlockStatus,.9,2.5,-6,6,3,4.5);		
	Crew.SetMembersPosRotOnEVA(_V(1.5,-1.2778,3.7),_V(0,3,0));
	doorselected=3;
		break;
		
	}
	
	}

void BELL222::SelectCockpitView (int CAM)
{

     switch (CAM) {
 case 0:  //PILOT
          SetCameraDefaultDirection (_V(0,0,1));
          SetCameraOffset (_V(.48,-1.1,4.1));
		  oapiCameraSetCockpitDir (0,0);
          break;
 case 1:  //PILOT
          SetCameraDefaultDirection (_V(0,0,1));
          SetCameraOffset (_V(-.48,-1.1,4.1));
		  oapiCameraSetCockpitDir (0,0);
          break;
 case 2:  //BELOW
          SetCameraDefaultDirection (_V(0,-1,0));
          SetCameraOffset (_V(0 ,-4.5181,  2.244843));
		  oapiCameraSetCockpitDir (0,0);
          break;

 }}




void BELL222::clbkPostCreation (void)

{
	


BELL222ID=ConnectToOrbiterSoundDLL(GetHandle());

RequestLoadVesselWave(BELL222ID,	BELL222Engines,"Sound\\_CustomVesselsSounds\\BELL222\\BELL222ENGINES.wav",BOTHVIEW_FADED_CLOSE);
RequestLoadVesselWave(BELL222ID,	BELL222Gear,"Sound\\_CustomVesselsSounds\\BELL222\\BELL222GEAR.wav",INTERNAL_ONLY);
RequestLoadVesselWave(BELL222ID,    BELL222Start,"Sound\\_CustomVesselsSounds\\BELL222\\BELLSTART.wav",BOTHVIEW_FADED_CLOSE);

//	RequestLoadVesselWave(MyID,MY500METERSOUND,"Sound\\OrbiterSound_SDK\\sound\\my500meter.wav",RADIO_SOUND);

	SetMyDefaultWaveDirectory("Sound\\_CustomVesselsSounds\\BELL222\\");


//ReplaceStockSound3(BELL222ID,"Sound\\Vessel\\MOONBASEALPHA\\ambient.wav",	REPLACE_COCKPIT_AMBIENCE_1);
SoundOptionOnOff(BELL222ID,PLAYMAINTHRUST,FALSE);
//ReplaceStockSound(BELL222ID,"Sound\\Vessel\\HH65\\HH65Engines.wav",	REPLACE_HOVER_THRUST);

//SoundOptionOnOff3(BELL222ID,PLAYHOVERTHRUST,TRUE);
//ReplaceStockSound3(BELL222ID,"Sound\\Vessel\\roll.wav",	REPLACE_RCS_THRUST_ATTACK);

SoundOptionOnOff(BELL222ID,PLAYATTITUDETHRUST,FALSE);

SoundOptionOnOff(BELL222ID,PLAYCOUNTDOWNWHENTAKEOFF,FALSE);

SoundOptionOnOff(BELL222ID,PLAYCABINAIRCONDITIONING,TRUE);

SoundOptionOnOff(BELL222ID,PLAYCABINRANDOMAMBIANCE,TRUE);

SoundOptionOnOff(BELL222ID,PLAYRADIOATC,FALSE);

SoundOptionOnOff(BELL222ID,DISPLAYTIMER,FALSE);

}


// Constructor
//BELL222::BELL222 (OBJHANDLE hObj, int fmodel)
//: VESSEL2 (hObj, fmodel)

BELL222::BELL222 (OBJHANDLE hObj, int fmodel)
: VESSEL2 (hObj, fmodel)
{
//GEARCOVER_status      = GEAR_UP;
//GEARCOVER_proc        = 0.0;
DOOR3_status      = GEAR_UP;
DOOR3_proc        = 0.0;
ROTORSTART=0.0;
GEAR_status      = GEAR_UP;
GEAR_proc        = 0.0;
DOOR4_status      = GEAR_UP;
DOOR4_proc        = 0.0;

DOOR1_status      = GEAR_UP;
DOOR1_proc        = 0.0;
DOOR2_status      = GEAR_UP;
DOOR2_proc        = 0.0;

IGNITION_check = NO_START;
iActiveDockNumber=0;
ROTOR=0;
ROTOR_proc        = 0.0;
ROTOR_SPEED=0;
LIFT_SPEED =.25;
DefineAnimations ();
ENGINESTART=0.0;	
}


void BELL222::clbkSetClassCaps (FILEHANDLE cfg)
{
	// physical specs
	SetSize (8.2);
	SetEmptyMass (6400);//15000.0  2389
	SetCW (0.3, 0.3, 0.6, 0.9);
	SetWingAspect (0.1);
	SetWingEffectiveness (0.1);
	SetCrossSections (_V(29.73,48.13,12.72));
	SetRotDrag (_V(1.5,1.5,1.5));
	if (GetFlightModel() >= 1) {
		SetPitchMomentScale (1e-4);
		SetBankMomentScale (1e-4);
	}
	SetPMI (_V(26.20,22.72,17.06));
	SetTrimScale (0.05);
	SetCameraOffset (_V(.48,-.5,4.9));
	
	SetTouchdownPoints  (_V(0,-2.45,9), _V(-4,-2.45,-9), _V(4,-2.45,-9));; //28
EnableTransponder (true);

 SetMaxWheelbrakeForce(200000);

const VECTOR3 PMI = _V(26.20,22.72,17.06);
	const VECTOR3 CS = _V(606, 614, 254);

//CreateAirfoil (LIFT_VERTICAL,   _V(0,0,-0.5), VLiftCoeff, 1, 1, 1);
//CreateAirfoil (LIFT_HORIZONTAL, _V(0,0,-4), HLiftCoeff, 1,  1, 1);

//Airfoils
 CreateAirfoil3(LIFT_VERTICAL,_V(0,0,-0.5),VLiftCoeff,0,0,1,1);
 CreateAirfoil3(LIFT_HORIZONTAL,_V(0,0,-4),HLiftCoeff,0,0,1,1);
//CreateAirfoil (LIFT_VERTICAL, _V(0,0.2,0), VLiftCoeff, 3, 3, 3);
	// wing and body lift+drag components

//	CreateAirfoil (LIFT_HORIZONTAL, _V(0,0,-17), HLiftCoeff, 3, 5, 1.0);
	// vertical stabiliser and body lift and drag components



 CreateControlSurface2(AIRCTRL_AILERON ,1,1,_V(7,-0.5,-15),0);
 CreateControlSurface2(AIRCTRL_AILERON ,1,1,_V(-7,-0.5,-15),0);
 CreateControlSurface2(AIRCTRL_ELEVATOR,1,1,_V(0,0,-15),0);
 CreateControlSurface2(AIRCTRL_RUDDER  ,1,1,_V(0,3,-16),0);

MAIN = AddMesh (oapiLoadMeshGlobal ("BELL222C"));
SetMeshVisibilityMode (MAIN, MESHVIS_ALWAYS);

MAINVC = AddMesh (oapiLoadMeshGlobal ("BELL222VC"));
SetMeshVisibilityMode (MAINVC, MESHVIS_VC);

BLADE = AddMesh (oapiLoadMeshGlobal ("BELL222BLADE"));
SetMeshVisibilityMode (BLADE, MESHVIS_ALWAYS);

DISC = AddMesh (oapiLoadMeshGlobal ("BELL222DISC"));
SetMeshVisibilityMode (DISC, MESHVIS_NEVER);



//SetMeshVisibilityMode (AddMesh (oapiLoadMeshGlobal ("BELL222F")), MESHVIS_ALWAYS ); //Main ship mesh
//SetMeshVisibilityMode (AddMesh (oapiLoadMeshGlobal ("BELL222F1")), MESHVIS_VC ); //Main ship mesh
//SetMeshVisibilityMode (AddMesh (oapiLoadMeshGlobal ("BELL222BLADE")), MESHVIS_ALWAYS ); //Main ship mesh
//SetMeshVisibilityMode (AddMesh (oapiLoadMeshGlobal ("BELL222DISC")), MESHVIS_NEVER ); //Main ship mesh




	// ***************** thruster definitions *******************
	

PROPELLANT_HANDLE hpr = CreatePropellantResource (PB_FUELMASS);

//THRUSTER_HANDLE th_att_rot[4], th_att_lin[4];		
th_hover[0] = CreateThruster (_V(0,3,0), _V(0,1,0), PB_MAXHOVERTH, hpr, PB_ISP);
		//AddExhaust (th_hover[i], 0.3, 0.5,_V(HoverEngineOfs[i].x,HoverEngineOfs[i].y,HoverEngineOfs[i].z),_V(0,-1,0));
		thg_hover = CreateThrusterGroup (th_hover, 1, THGROUP_HOVER);

	
	
	th_att_rot[0] = CreateThruster (_V(0.0, 0, 1), _V(0,-1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[1] = CreateThruster (_V(0.0, 0, -1), _V(0,1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[2] = CreateThruster (_V(0.0, 0, 1), _V(0,1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[3] = CreateThruster (_V(0.0, 0, -1), _V(0,-1,0), PB_MAXRCSTH, hpr, PB_ISP);
	CreateThrusterGroup (th_att_rot,   2, THGROUP_ATT_PITCHDOWN);
	CreateThrusterGroup (th_att_rot+2,   2, THGROUP_ATT_PITCHUP);

	th_att_rot[0] = CreateThruster (_V( 1,0,0), _V(0,-1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[1] = CreateThruster (_V(-1,0,0), _V(0,1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[2] = CreateThruster (_V(1,0,0), _V(0,1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[3] = CreateThruster (_V(-1,0,0), _V(0,-1,0), PB_MAXRCSTH, hpr, PB_ISP);
	CreateThrusterGroup (th_att_rot, 2, THGROUP_ATT_BANKRIGHT);
	CreateThrusterGroup (th_att_rot+2, 2, THGROUP_ATT_BANKLEFT);
	
	th_att_rot[0] = CreateThruster (_V( 14.6,0,0), _V(0,0,-1), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[1] = CreateThruster (_V(-14.6,0,0), _V(0,0,1), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[2] = CreateThruster (_V( 14.6,0,0), _V(0,0,1), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_rot[3] = CreateThruster (_V(-14.6,0,0), _V(0,0,-1), PB_MAXRCSTH, hpr, PB_ISP);
	CreateThrusterGroup (th_att_rot, 2, THGROUP_ATT_YAWRIGHT);
	CreateThrusterGroup (th_att_rot+2, 2, THGROUP_ATT_YAWLEFT);


	th_att_lin[0] = CreateThruster (_V( 1,0,0), _V(0,1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[1] = CreateThruster (_V(-1,0,0), _V(0,1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[2] = CreateThruster (_V(1,0,0), _V(0,-1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[3] = CreateThruster (_V(-1,0,0), _V(0,-1,0), PB_MAXRCSTH, hpr, PB_ISP);	
		
	
	CreateThrusterGroup (th_att_lin,   2, THGROUP_ATT_UP);
	CreateThrusterGroup (th_att_lin+2, 2, THGROUP_ATT_DOWN);



	th_att_lin[0] = CreateThruster (_V( 1,0,0), _V(0,0,1), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[1] = CreateThruster (_V(-1,0,0), _V(0,0,1), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[2] = CreateThruster (_V(1,0,0), _V(0,0,-1), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[3] = CreateThruster (_V(-1,0,0), _V(0,0,-1), PB_MAXRCSTH, hpr, PB_ISP);	

	CreateThrusterGroup (th_att_lin,   2, THGROUP_ATT_FORWARD);
	CreateThrusterGroup (th_att_lin+2, 2, THGROUP_ATT_BACK);


	th_att_lin[0] = CreateThruster (_V(0,0,1), _V(1,0,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[1] = CreateThruster (_V(0,0,-1), _V(1,0,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[2] = CreateThruster (_V(0,0,1), _V(-1,0,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_att_lin[3] = CreateThruster (_V(0,0,-1), _V(-1,0,0), PB_MAXRCSTH, hpr, PB_ISP);	
	CreateThrusterGroup (th_att_lin,   2, THGROUP_ATT_RIGHT);
	CreateThrusterGroup (th_att_lin+2, 2, THGROUP_ATT_LEFT);

			

//beacons
	 static VECTOR3 beaconpos[5] = {{-2.327,    -1.37,    2.138}, //red
                                   {  2.327,    -1.37,    2.138},  //red
                                   {0,      -1.774,  2.1}, //red
                                   {  .193,   2.42, -7.35},   //blue
                                   {  .193,   .222, -7.14}
	                              };

    static VECTOR3 beaconcol[5] = {{1,0,0}, //red
	                               {0,1,0}, //green
	                               {1,0,0}, //red
	                               {1, 0, 0},//red
								  	{1, 1, 1} //white                        
	};

    
	for (int i = 0; i < 2; i++) {
        beacon[i].shape = BEACONSHAPE_STAR;
        beacon[i].pos = beaconpos+i;
        beacon[i].col = beaconcol+i;
        beacon[i].size = 0.2;
        beacon[i].falloff =  0.3;
        beacon[i].period = 0;
        beacon[i].duration = 0;
        beacon[i].tofs = (6-i)*0.2;
        beacon[i].active = true;
        AddBeacon (beacon+i);
    }
	
	
	
	for (int i = 2; i < 5; i++) {
        beacon[i].shape = BEACONSHAPE_STAR;
        beacon[i].pos = beaconpos+i;
        beacon[i].col = beaconcol+i;
        beacon[i].size = 0.2;
        beacon[i].falloff =  0.3;
        beacon[i].period = 0.8;
        beacon[i].duration = 0.3;
        beacon[i].tofs = (6-i)*0.2;
        beacon[i].active = true;
        AddBeacon (beacon+i);
    }

SelectedUmmuMember=0;
	clbkSetClassCaps_UMMu();
		clbkSetClassCapsUCgo();


}
void BELL222::clbkSetClassCapsUCgo (void)
{
		//UCGO 2.0 Initialisation, cargo slot pos, rot declaration
	hUcgo.Init(GetHandle());
	// in contrary of the PDF code we declare 6 slots
	// because it's fun :)

	//hUcgo.DeclareCargoSlot(0,_V(-.6131244,.037,3.048831),_V(0,0,0)); // slot 0
//	hUcgo.DeclareCargoSlot(1,_V(-2.460896,.037, 1.856179),_V(0,0,0)); // slot 1

	hUcgo.DeclareCargoSlot(0,_V( 0,-2,.14),_V(0,0,0)); // slot 0
	




	hUcgo.SetCargoMeshVisibility (0,MESHVIS_ALWAYS);	
	

	// UCGO 2.0 Parameters settings
	hUcgo.SetReleaseSpeedInSpace(0.10f);	   // release speed of cargo in space in m/s
	hUcgo.SetMaxCargoMassAcceptable(50000.0);   // max cargo mass in kg that your vessel can carry
	hUcgo.SetGrappleDistance(15);		       // grapple distance radius in meter from center of ship
	hUcgo.SetGlobalGroundReleasePos(_V(6,0,0));// global release pos on ground

	// UCGO Variables initialisation
	cCargoHudDisplay[0]=0;						// Cargo hud display char variable
	dCargHudMessageDelay=0;						// Cargo hud display delay
	iSelectedCargo=-1;							// for the selection of cargos (-1 mean "default" see header)
	// welcome message with keys for users
	strcpy(SendCargHudMessage(),"Cargo key: C/SHF+C = grapple/release, 9/SHF+9 = snc editor add cargo, 8=infos on cargos");
}

// =======================================================
// UMMU Class Caps
// =======================================================

void BELL222::clbkSetClassCaps_UMMu(void)
{
	//--------------------------------------------------------------
	// InitUmmu
	// initialisation of Ummu must be done first ! return of 1 mean OK 
	// return of -999 mean Ummu addon is not installed in user's Orbiter, return of -1 
	// mean misc error. If error simply all function will fail silently 
	// and there will be no MMu. It's a good idea to warn the user. 
	// (see function "WarnUserUMMUNotInstalled" below)
	Crew.InitUmmu(GetHandle());	
	//--------------------------------------------------------------

	//--------------------------------------------------------------
	// GetUserUMmuVersion
	// this check wich version of UMmu addon the user have in his orbiter directory.
	// this may be usefull for future version with more function so you can check
	// if user installation support the new functions. Return -1 on error (not installed, version cannot be read)
	// or version number in float value (ie: 2.0="2.0" version etc etc)
	float UMmuVersion=Crew.GetUserUMmuVersion();

	//--------------------------------------------------------------
	// DefineAirLockShape
	// We set the airlock shape and state, this virtual box will be the one
	// into were a Ummu asking to reenter will be taken in account
	// first parameter is airlock door state (OPEN=TRUE) and other are X,X1,Y,Y1 and Z,Z1 
	// min and max coordinate for this virtual box (vessel local coordinate)
	// Pay attention to reenter when landed (if suitable) and make the box large enough so 
	// it's not a pain for the user to find airlock's entry. (See PDF doc)
	Crew.DefineAirLockShape(FALSE,-3,0,-6,6,3,6);			// Airlock open, 2 meter large 4 meter high 6 meter long (vessel local coordinate)

	//--------------------------------------------------------------
	// SetMembersPositionOrientationOnEVA
	// We define here were the Ummu will appear when they make an EVA
	// first parameter is position second is orientation, take care not to make
	// them appear to high on ground (will fall and die) or to low (Orbiter "light speed" bug)
	Crew.SetMembersPosRotOnEVA(_V( -1.88 ,-1.2778,1.88),_V(0,0,0));	// 3 meters in front of ship (z) facing direction of ship (vessel local coordinate)

	//---------------------------------------------------------------
	// finally set the maximum seat available in this ship, default is
	// 8 but it can go from 1 to 100
	// BAD IDEA: using this to "close" your ship, use "SetAirlockDoorState" instead.
	Crew.SetMaxSeatAvailableInShip(6);

	//----------------------------------------------------------------
	// OPTIONAL OPTIONAL OPTIONAL OPTIONAL OPTIONAL OPTIONAL OPTIONAL
	// DeclareActionArea
	// Ever wanted to be able to open a door, repair a system or trigger something in your vessel from an UMMU ?
	// Here come a new feature of UMMU 2.0: Action area. See UMmuSDK.h and PDF doc for complete explanation and see
	// "DetectActionAreaActivated" below.
	Crew.DeclareActionArea(0,_V(-1.5,0,6),2,TRUE,"action_door.wav","Open/Close Left Door");
	Crew.DeclareActionArea(1,_V(1.5,0,6),2,TRUE, "action_door.wav","Open/Close Right Door");
	Crew.DeclareActionArea(2,_V(-1.50,0,3.37),2,TRUE, "action_door.wav","Open/Close Left Rear Door");
		Crew.DeclareActionArea(3,_V(1.5,0,3.37),2,TRUE, "action_door.wav","Open/Close Right Rear Door");

	//Crew.DeclareActionArea(3,_V(65.5,0,-11.75),2,TRUE, "action_door.wav","Outer AIrlock Active");

	//Crew.DeclareActionArea(3,_V(0,0,-5),2.5,TRUE,"action_activated.wav","You are behind the ship");
	//iActionAreaDemoStep=0;	// this is just to show a feature of action area, see below "DetectActionAreaActivated"

	//--------------------------------------------------------------
	// AddCrewMember
	// We'll add four default members for when the ship is spawned by Orbiter's scenario editor. 
	// parameters are name, age, cardiac pulse,weight (in kilogramm) and Function (Misc ID)
	// max four characters wich define the spacesuit used. (see UmmuMiscID in UMuSDK.h header)
	// Return 1 on success -1 on error (probably vessel full, name>25 char 
	// age, pulse or weight out of realistic range or MiscID>4 char)
	//Crew.AddCrewMember("Peter Falcon",41,65,74,"Capt");		//(for name and id a-z A-Z 0-9 characters only)
	//Crew.AddCrewMember("Fanny Gorgeous",27,67,55,"Eng");	//(for name and id a-z A-Z 0-9 characters only)
	//Crew.AddCrewMember("George HealGood",15,70,45,"Doc");	//(for name and id a-z A-Z 0-9 characters only)
	//Crew.AddCrewMember("Albert Jr Falcon",15,70,45);		//(for name and id a-z A-Z 0-9 characters only)
	//Crew.AddCrewMember("John HealGood",15,70,45,"Doc");	//(for name and id a-z A-Z 0-9 characters only)
	//Crew.AddCrewMember("Robert Jr Falcon",15,70,45);		//(for name and id a-z A-Z 0-9 characters only)

	SelectedUmmuMember =0;  // our current selected member


	// The HUD display method variables, see PDF doc
	cUmmuHudDisplay[0] =0;	// Initialisation of UMmu hud char variable
	dHudMessageDelay =0;	// Initialisation of UMmu delay variable
	strcpy(SendHudMessage(),"Welcome aboard ! E=EVA 1,2=select UMmu D=Open/Close airlock S=info M=add crew");

	// The Add mmu without scenery editor variable see PDF doc
	cAddUMmuToVessel[0]=0;
}








void BELL222::clbkPostStep(double simt, double simdt, double mjd)
{



//---------------------------------------------------------------------------
	// ProcessUniversalMMu
	// Here the routine that detect if someone entered the ship (eva or transfer)
	// No need to manage anything here all is automatic, crew is added to your ship, ship's weight is updated,
	// and UMmu vessel is automatically deleted from Orbiter. You may just look the return
	// code to see if someone entered and display wathewer message on panel or other.
	// notice it's FPS friendly, function process only 4 time per second not each frame 
	// and return immediately if airlock closed or no Ummu is detected in vincinity. 
	int ReturnCode=Crew.ProcessUniversalMMu();
	switch(ReturnCode)
	{
	case UMMU_TRANSFERED_TO_OUR_SHIP: 
		sprintf(SendHudMessage(),"%s \"%s\" aged %i was transfered to our ship",
		Crew.GetCrewMiscIdByName(Crew.GetLastEnteredCrewName()),Crew.GetLastEnteredCrewName()
		,Crew.GetCrewAgeByName(Crew.GetLastEnteredCrewName()));
		break;
	case UMMU_RETURNED_TO_OUR_SHIP:
		sprintf(SendHudMessage(),"%s \"%s\" aged %i entered into our ship",
		Crew.GetCrewMiscIdByName(Crew.GetLastEnteredCrewName()),
		Crew.GetLastEnteredCrewName(),Crew.GetCrewAgeByName(Crew.GetLastEnteredCrewName()));
		break;
	}
	if(GroundContact()==TRUE)
	{
		// we check vertical speed
		//int I;
		VECTOR3 vHorizonAirspeedVector={0};
		GetHorizonAirspeedVector (vHorizonAirspeedVector);
		double VertSpeed		=vHorizonAirspeedVector.y;
		if(VertSpeed<-3)
		{
			// we touched ground with more than -3 m/s, sorry dude, time to kill you all :(
			//for(I=0;I<Crew.GetCrewTotalNumber();I++)
			//{
		//		Crew.SetCrewMemberPulseBySlotNumber(I,0);	// set cardiac pulse to zero
		//	}
		//	strcpy(SendHudMessage(),"Oooh no ! Crash - All crew aboard killed");
		}

		// TIPS: the vertical speed is often reset to zero when there is ground contact
		// this may bug somewhat the death of your crew.
		// to have an accurate VertSpeed at touchdown I recommand to record it at very END 
		// of timestep and use this "old" value. The next frame you'll have the vertspeed value 
		// of *last frame* just before the crash (GroundContact). This ensure an accurate 
		// verticalspeed value. (keep this value in your vessel class and don't forget to 
		// initialize it at zero in setclasscap)
	}
	int ActionAreaReturnCode=Crew.DetectActionAreaActivated();
	
	if(ActionAreaReturnCode>-1)
	{		// this is just an example, we have four area declared
		// action area ID 0 triggered 
		if(ActionAreaReturnCode==0)
		{
		RevertDOOR1();
				//RevertDOOR2();

		Crew.SetAirlockDoorState(!Crew.GetAirlockDoorState());
		}
		if(ActionAreaReturnCode==1)
		{
		RevertDOOR2();
				//RevertDOOR2();

		Crew.SetAirlockDoorState(!Crew.GetAirlockDoorState());
		}
		if(ActionAreaReturnCode==2)
		{
		
				RevertDOOR3();

		Crew.SetAirlockDoorState(!Crew.GetAirlockDoorState());
		}
if(ActionAreaReturnCode==3)
		{
		
				RevertDOOR4();

		Crew.SetAirlockDoorState(!Crew.GetAirlockDoorState());
		}

	}
//sprintf(oapiDebugString(),"anim %2.2f", DOOR_proc);

	//---------------------------------------------------------------------------
	// WarnUserUMMUNotInstalled - IMPORTANT helper
	// Put here this function and users will be automatically warned if they don't have
	// UMMU installed or if it's outdated. Warning text duration is 20 seconds and text is:
	// [AddonName] require "Universal MMU" ver 2.0 or higher. Download at www.orbiter.dansteph.com (message countdown in seconds)
	// an additonal "your version of UMMU is outdated" is displayed the last 5 seconds if they have version lower than 2.0
	Crew.WarnUserUMMUNotInstalled("BELL222");



	// THIS IS FOR ADDING CREW SEE PDF doc "Allow user to add crew to your ship 
	// without scenery editor"
	AddUMmuToVessel();


double vsAirSpeed = GetAirspeed();	

VECTOR3 speedvec; // first we define our vector which will recieve the data
oapiGetFocusShipAirspeedVector(&speedvec);//then we retrieve its x,y,z

if (GroundContact()==false && GetAirspeed() >72 && (speedvec.z>0))
{AddForce(_V(0,0,-8.5e5),_V(0,0,0));}

if (GroundContact()==false && GetAirspeed() >72 && (speedvec.z<0))
{AddForce(_V(0,0,8.5e5),_V(0,0,0));}





if (DOOR1_status >= GEAR_RAISING) {
		double da = simdt * LIFT_SPEED;
		if (DOOR1_status == GEAR_RAISING) {
			if (DOOR1_proc > 0.0) DOOR1_proc = max (0.0, DOOR1_proc-da);
			else                DOOR1_status = GEAR_UP;
		} else {
			if (DOOR1_proc < 1.0) DOOR1_proc = min (1.0, DOOR1_proc+da);
			else                DOOR1_status = GEAR_DOWN;
		}

SetAnimation (anim_DOOR1, DOOR1_proc);	

}
if (DOOR2_status >= GEAR_RAISING) {
		double da = simdt * LIFT_SPEED;
		if (DOOR2_status == GEAR_RAISING) {
			if (DOOR2_proc > 0.0) DOOR2_proc = max (0.0, DOOR2_proc-da);
			else                DOOR2_status = GEAR_UP;
		} else {
			if (DOOR2_proc < 1.0) DOOR2_proc = min (1.0, DOOR2_proc+da);
			else                DOOR2_status = GEAR_DOWN;
		}

SetAnimation (anim_DOOR2, DOOR2_proc);	

}



if (DOOR3_status >= GEAR_RAISING) {
		double da = simdt * LIFT_SPEED;
		if (DOOR3_status == GEAR_RAISING) {
			if (DOOR3_proc > 0.0) DOOR3_proc = max (0.0, DOOR3_proc-da);
			else                DOOR3_status = GEAR_UP;
		} else {
			if (DOOR3_proc < 1.0) DOOR3_proc = min (1.0, DOOR3_proc+da);
			else                DOOR3_status = GEAR_DOWN;
		}

SetAnimation (anim_DOOR3, DOOR3_proc);	
}

if (DOOR4_status >= GEAR_RAISING) {
		double da = simdt * LIFT_SPEED;
		if (DOOR4_status == GEAR_RAISING) {
			if (DOOR4_proc > 0.0) DOOR4_proc = max (0.0, DOOR4_proc-da);
			else                DOOR4_status = GEAR_UP;
		} else {
			if (DOOR4_proc < 1.0) DOOR4_proc = min (1.0, DOOR4_proc+da);
			else                DOOR4_status = GEAR_DOWN;
		}

SetAnimation (anim_DOOR4, DOOR4_proc);	
}







if (GEAR_status >= GEAR_RAISING) {
		double da = simdt * LIFT_SPEED;
		if (GEAR_status == GEAR_RAISING) {
			if (GEAR_proc > 0.0) GEAR_proc = max (0.0, GEAR_proc-da);
			else                GEAR_status = GEAR_UP;
		} else {
			if (GEAR_proc < 1.0) GEAR_proc = min (1.0, GEAR_proc+da);
			else                GEAR_status = GEAR_DOWN;
		}


SetAnimation (anim_GEAR, GEAR_proc);		

}


STICK1Z=GetThrusterGroupLevel (THGROUP_ATT_PITCHUP);
STICK1Z1=GetThrusterGroupLevel (THGROUP_ATT_PITCHDOWN);

if (STICK1Z==1)STICK1Z2 =1;
if (STICK1Z1==1)STICK1Z2 =0;
if ((STICK1Z==0)&& (STICK1Z1==0))STICK1Z2 =.5;

SetAnimation (anim_STICKZ, STICK1Z2);
SetAnimation (anim_STICKZ1, STICK1Z2);



STICK1X=GetThrusterGroupLevel (THGROUP_ATT_BANKRIGHT);
STICK1X1=GetThrusterGroupLevel (THGROUP_ATT_BANKLEFT);

if (STICK1X==1)STICK1X2 =1;
if (STICK1X1==1)STICK1X2 =0;
if ((STICK1X==0)&& (STICK1X1==0))STICK1X2 =.5;


SetAnimation (anim_STICKX, STICK1X2);
SetAnimation (anim_STICKX1, STICK1X2);


PEDALR=GetThrusterGroupLevel (THGROUP_ATT_YAWRIGHT);
PEDALL=GetThrusterGroupLevel (THGROUP_ATT_YAWLEFT);
if (PEDALR==1)PEDALBOTH =1;
if (PEDALL==1)PEDALBOTH =0;
if ((PEDALR==0)&& (PEDALL==0))PEDALBOTH =.5;

 SetAnimation (anim_PEDAL1, PEDALBOTH);
 SetAnimation (anim_PEDAL2, PEDALBOTH);


ROTOR1=(GetThrusterLevel (th_hover[0]));
	 SetAnimation (anim_COLL, ROTOR1);











if (IGNITION_check == NO_START) {
    
        SetThrusterGroupLevel(thg_hover,0);
		
		SetThrusterLevel(th_hover[0],0);
		
		SetThrusterMax0 (th_hover[0] ,0);
		
			ROTORSTART = ROTORSTART-simdt;
			

	SetMeshVisibilityMode( BLADE, MESHVIS_ALWAYS ); 
SetMeshVisibilityMode( DISC, MESHVIS_NEVER ); 

}
if (ROTORSTART>6){
ROTOR_SPEED= .9;
}

if ((ROTORSTART>0) && (IGNITION_check == YES_START)&& (ENGINESTART >20))
{ROTOR_SPEED=ROTOR_SPEED+.02;
if (ROTOR_SPEED>.9) ROTOR_SPEED=.9;
}

if ((ROTORSTART<6) && (IGNITION_check == NO_START))
{ROTOR_SPEED=ROTOR_SPEED-.02;
if (ROTOR_SPEED<0) ROTOR_SPEED=0;
}


double da = simdt * ROTOR_SPEED;
	ROTOR_proc=ROTOR_proc+da;
if (ROTOR_proc>1)ROTOR_proc=0;




if (ROTORSTART<0)ROTORSTART=0;




SetAnimation (anim_ROTOR, ROTOR_proc);		





		//sprintf(oapiDebugString(),"rotortimer %2.2f rotor %2.2f rotord %2.2f", ROTOR_SPEED,ROTOR_SPEED,ROTORSTART);
//
if (IGNITION_check == YES_START){
		
		
		SetThrusterMax0 (th_hover[0],8.5e5);
		//SetThrusterLevel(th_hover[0],0.1);
	//	sprintf(oapiDebugString(),"ATM %2.2f ", ROTORSTART);

ENGINESTART=ENGINESTART+.1;

if (ENGINESTART>20){
ROTORSTART = ROTORSTART+simdt;
if (ROTORSTART>6){
	ROTORSTART=6.1;
	SetMeshVisibilityMode( BLADE, MESHVIS_NEVER ); 
SetMeshVisibilityMode( DISC, MESHVIS_ALWAYS ); 
}

}}




  












ATMD1= GetAtmDensity () ;

ATMadjusted=(8.5e5*ATMD1);

SetThrusterMax0 (th_hover[0],ATMadjusted);
//SetThrusterMax0 (hover_th, double maxth0) ATMadjusted

//sprintf(oapiDebugString(),"ATM %2.2f ATMADJU %2.2f ATM2 %2.2f ATM3 %2.2f", ATMD1,ATMadjusted,ATMD2,ATMD3);
ATMD2=((ATMD1-.7)*1.5);
ATMD3=(ATMD2*8.5e5);
SetThrusterMax0 (th_hover[0],ATMD3);


//if (GetThrusterLevel(th_hover[0]) ==0){
//PlayVesselWave(BELL222Engines,NOLOOP,0);
//	}

  //  if (GetThrusterLevel(th_hover[0]) >0.1){
//PlayVesselWave(BELL222Engines,LOOP,255);
//	}

  //  if (GetThrusterLevel(th_hover[0]) ==0.1){
//PlayVesselWave(BELL222Engines,LOOP,128);
//	}





}
	    
  










void BELL222::DefineAnimations(void)

{
  	

  	static UINT EGrp20[2] = {17,25};//rear gear
    static MGROUP_ROTATE GEAR1 (0,EGrp20, 2, _V( 0, -1.657034,  2.110673), _V(1,0,0), (float)(-110*RAD));//

	
  	static UINT EGrp24[2] = {18,26};//NOSE WHEEL
    static MGROUP_TRANSLATE GEAR2 (0,EGrp24, 2, _V(0, .6 ,0));//

	static UINT EGrp25[1] = {45};//gearcover1
    static MGROUP_ROTATE GEAR3 (0,EGrp25, 1, _V(   .30, -1.745179, 7.081), _V(-.01,.1,1), (float)(-90*RAD));//

	static UINT EGrp126[1] = {44};//gearcover2
    static MGROUP_ROTATE GEAR4A (0,EGrp126, 1, _V( -.30, -1.765179, 7.081), _V(-.01,.1,1), (float)(90*RAD));//

      //.015,-.20,.9   .025,-.255,.9
anim_GEAR = CreateAnimation (0); 

AddAnimationComponent  (anim_GEAR, 0, .5, &GEAR1) ; //rear wheels 
//AddAnimationComponent  (anim_GEAR, 0, .3, &GEAR2) ;  //nose rotate 
AddAnimationComponent  (anim_GEAR, 0, .5, &GEAR2) ;  //nose translate 

AddAnimationComponent  (anim_GEAR, .5, 1, &GEAR3) ;   
AddAnimationComponent  (anim_GEAR, .5, 1, &GEAR4A) ;   






  	static UINT EGrp12[3] = {37,5,52};//DOOR

   	
    static MGROUP_ROTATE DOOR (0,EGrp12, 3, _V( -1.0 , -1.34,  5.879), _V(0,1,-.2), (float)(90*RAD));//
	  
     	static UINT EGrp121[3] = {40,5,55};//DOOR

   	
    static MGROUP_ROTATE DOORA (1,EGrp121, 3, _V( -1.0 , -1.34,  5.879), _V(0,1,-.2), (float)(90*RAD));//
 
      
anim_DOOR1 = CreateAnimation (0); 
AddAnimationComponent  (anim_DOOR1, 0, 1, &DOOR) ;   
AddAnimationComponent  (anim_DOOR1, 0, 1, &DOORA) ;   


   	
	  	static UINT EGrp13[3] = {39,8,53};//
     static MGROUP_ROTATE DOOR2 (0,EGrp13, 3, _V(1.0 , -1.34,  5.879), _V(0,1,-.2), (float)(-90*RAD));//
  
    	  	static UINT EGrp131[3] = {42,8,56};//

     static MGROUP_ROTATE DOOR2A (1,EGrp131, 3, _V(1.0 , -1.34,  5.879), _V(0,1,-.2), (float)(-90*RAD));//
  

      
anim_DOOR2 = CreateAnimation (0); 
AddAnimationComponent  (anim_DOOR2, 0, 1, &DOOR2) ;   
AddAnimationComponent  (anim_DOOR2, 0, 1, &DOOR2A) ;   





 	static UINT EGrp128[4] = {9,43,40,54};//DOOR

   	
    static MGROUP_ROTATE DOOR3A (1,EGrp128, 4, _V( -1.1 ,-.9699696,  4.282504), _V(0,1,-.2), (float)(90*RAD));//
  
	 	static UINT EGrp129[4] = {9,43,46,57};//DOOR

   	
    static MGROUP_ROTATE DOOR3 (0,EGrp128, 4, _V( -1.1 ,-.9699696,  4.282504), _V(0,1,-.2), (float)(90*RAD));//
  	
  
    
      
anim_DOOR3 = CreateAnimation (0); 
AddAnimationComponent  (anim_DOOR3, 0, 1, &DOOR3) ;   
AddAnimationComponent  (anim_DOOR3, 0, 1, &DOOR3A) ;   


	  	static UINT EGrp134[4] = {10,42,41,55};//DOOR

     static MGROUP_ROTATE DOOR4A (0,EGrp134, 4, _V( 1.1 ,-.9699696,  4.282504), _V(0,1,.2), (float)(-90*RAD));//
  
  	  	static UINT EGrp136[4] = {10,43,46,58};//DOOR

     static MGROUP_ROTATE DOOR4B (1,EGrp136, 4, _V( 1.1 ,-.9699696,  4.282504), _V(0,1,.2), (float)(-90*RAD));//

    
      
anim_DOOR4 = CreateAnimation (0); 
AddAnimationComponent  (anim_DOOR4, 0, 1, &DOOR4A) ;   
AddAnimationComponent  (anim_DOOR4, 0, 1, &DOOR4B) ;   



	//RIGHT STICK FORWARD/BACK
static UINT EGrp40[1] = {20};
    static MGROUP_ROTATE STICKZ (0,EGrp40, 1, _V(0.55211, -1.798234,  5.523), _V(1,0,0), (float)(-20*RAD));//

	static UINT EGrp41[1] = {20};//VC
    static MGROUP_ROTATE STICKZA (1,EGrp41, 1, _V(0.55211, -1.798234,  5.523), _V(1,0,0), (float)(-20*RAD));//

	anim_STICKZ = CreateAnimation (.5);

AddAnimationComponent  (anim_STICKZ, 0, 1, &STICKZ) ;  
AddAnimationComponent  (anim_STICKZ, 0, 1, &STICKZA) ;  

//LEFT STICK FORWARD/BACK
static UINT EGrp43[1] = {21};
static MGROUP_ROTATE STICKZ1 (0,EGrp43, 1, _V(0.55211, -1.798234,  5.722467), _V(1,0,0), (float)(-20*RAD));//

static UINT EGrp46[1] = {21};//VC
static MGROUP_ROTATE STICKZB (1,EGrp46, 1, _V(0.55211, -1.798234,  5.722467), _V(1,0,0), (float)(-20*RAD));//

anim_STICKZ1 = CreateAnimation (0); 

AddAnimationComponent  (anim_STICKZ1, 0, 1, &STICKZ1) ;  
AddAnimationComponent  (anim_STICKZ1, 0, 1, &STICKZB) ;  

//RIGHTSTICK LEFT/RIGHT
static UINT EGrp45[1] = {20};//
static MGROUP_ROTATE STICKX (0,EGrp41, 1, _V(.579,  -1.9685, -1.509433), _V(0,0,1), (float)(-20*RAD));//

static UINT EGrp50[1] = {20};//VC
static MGROUP_ROTATE STICKX1A (1,EGrp50, 1, _V(.579,  -1.9685, -1.509433), _V(0,0,1), (float)(-20*RAD));//

anim_STICKX = CreateAnimation (.5); 

AddAnimationComponent  (anim_STICKX, 0, 1, &STICKX) ;  
AddAnimationComponent  (anim_STICKX, 0, 1, &STICKX1A) ;  
//LEFTSTICK RIGHT/BACK
static UINT EGrp44[1] = {21};//
static MGROUP_ROTATE STICKX1 (0,EGrp44, 1, _V(-.579,  -1.9685, -1.509433), _V(0,0,1), (float)(-20*RAD));//

static UINT EGrp51[1] = {21};//VC
static MGROUP_ROTATE STICKX1B (1,EGrp51, 1, _V(-.579,  -1.9685, -1.509433), _V(0,0,1), (float)(-20*RAD));//

anim_STICKX1 = CreateAnimation (.5);


AddAnimationComponent  (anim_STICKX1, 0, 1, &STICKX1) ;  
AddAnimationComponent  (anim_STICKX1, 0, 1, &STICKX1B) ;  

static UINT EGrp42[5] = {19,30,31,32,33};//COLL
static MGROUP_ROTATE COLL (0,EGrp42, 5, _V(0.285955, -1.82811,  5.145965), _V(1,0,0), (float)(-30*RAD));//

static UINT EGrp55[5] = {19,30,31,32,33};//VC
static MGROUP_ROTATE COLLA (1,EGrp55, 5, _V(0.285955, -1.82811,  5.145965), _V(1,0,0), (float)(-30*RAD));//

anim_COLL = CreateAnimation (0); 
	
AddAnimationComponent  (anim_COLL, 0, 1, &COLL) ;  
AddAnimationComponent  (anim_COLL, 0, 1, &COLLA) ;  



//LEFT PEDAL

static UINT EGrp47[1] = {52};//COLL
static MGROUP_ROTATE PEDALL (0,EGrp47, 1, _V(0.242514, -1.753422,  5.682361), _V(1,0,0), (float)(-15*RAD));//

static UINT EGrp52[1] = {49};//COLL
static MGROUP_ROTATE PEDALL1 (1,EGrp52, 1, _V(0.242514, -1.753422,  5.682361), _V(1,0,0), (float)(-15*RAD));//

anim_PEDAL1 = CreateAnimation (0.5); 

AddAnimationComponent  (anim_PEDAL1, 0, 1, &PEDALL) ;  
AddAnimationComponent  (anim_PEDAL1, 0, 1, &PEDALL1) ;  
//PEDAL RIGHT
static UINT EGrp48[1] = {53};//
static MGROUP_ROTATE PEDALR (0,EGrp48, 1, _V(0.242514, -1.753422,  5.682361), _V(1,0,0), (float)(15*RAD));//

static UINT EGrp53[1] = {50};//VC
static MGROUP_ROTATE PEDALR1 (1,EGrp53, 1, _V(0.242514, -1.753422,  5.682361), _V(1,0,0), (float)(15*RAD));//

anim_PEDAL2 = CreateAnimation (0.5); 

AddAnimationComponent  (anim_PEDAL2, 0, 1, &PEDALR) ;  
AddAnimationComponent  (anim_PEDAL2, 0, 1, &PEDALR1) ;  





//ROTOR BLADES
  static UINT EGrp10[2] = {1,2};//rotor1

  static MGROUP_ROTATE ROTOR (2,EGrp10, 2, _V( 0  ,2.468162,  2.513511), _V(0,1,0), (float)(-360*RAD));//MAIN ROTOR


 static UINT EGrp39[1] = {1};//rotor1

  static MGROUP_ROTATE ROTORA (0,EGrp39, 1, _V( 0 , 2.468162,  2.513511), _V(0,1,0), (float)(-360*RAD));//MAIN ROTOR

//static UINT EGrp29[1] = {1};//rotor1

  //static MGROUP_ROTATE ROTORB (0,EGrp29, 1, _V( 0 , 2.468162,  2.513511), _V(0,1,0), (float)(-360*RAD));//MAIN ROTOR
//AddAnimationComponent  (anim_ROTOR, 0, 1, &ROTORB) ;  

static UINT EGrp124[1] ={0};//rotor2a

static MGROUP_ROTATE ROTORC (0,EGrp124, 1, _V( 0,  .3433884, -6.536881), _V(1,0,0), (float)(-360*RAD));//geardoor2

static UINT EGrp11[2] ={0,3};//rotor2a

static MGROUP_ROTATE ROTORD (2,EGrp11, 2, _V( -0.430165, .343481, -6.536069), _V(1,0,0), (float)(-360*RAD));//geardoor2

 static UINT EGrp15[1] = {0};//rotor1

  static MGROUP_ROTATE ROTOR2 (3,EGrp15, 1, _V( 0 , 2.430378,  2.500495), _V(0,1,0), (float)(-360*RAD));//MAIN ROTOR

static UINT EGrp38[1] ={1};//rotor2a

static MGROUP_ROTATE ROTOR3 (3,EGrp38, 1, _V( -0.430165, .343481, -6.536069), _V(1,0,0), (float)(-360*RAD));//geardoor2




anim_ROTOR = CreateAnimation (0); 
AddAnimationComponent  (anim_ROTOR, 0, 1, &ROTOR) ;  //blades
AddAnimationComponent  (anim_ROTOR, 0, 1, &ROTORA) ;  //main model
AddAnimationComponent  (anim_ROTOR, 0, 1, &ROTORC) ;  //vc model
AddAnimationComponent  (anim_ROTOR, 0, 1, &ROTORD) ;  //vc model
AddAnimationComponent  (anim_ROTOR, 0, 1, &ROTOR2) ;
AddAnimationComponent  (anim_ROTOR, 0, 1, &ROTOR3) ;













}
DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
return new BELL222 (hvessel, flightmodel);
}

DLLCLBK void ovcExit (VESSEL *vessel)
{
if (vessel) delete (BELL222*)vessel;
}
char *BELL222::SendCargHudMessage(void)
{
	dCargHudMessageDelay=15; // 15 seconds display delay for msg
	return cCargoHudDisplay;
}


// --------------------------------------------------------------
// Keyboard interface handler (buffered key events)
// --------------------------------------------------------------
int BELL222::clbkConsumeBufferedKey(DWORD key, bool down, char *kstate)
{
	// only process keydown events
	if (!down) 
		return 0; 
		if(key==OAPI_KEY_9&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		sprintf(SendCargHudMessage(),"%s - selected",hUcgo.ScnEditor_SelectNextCargoAvailableOnDisk());
		return 1;
	}
	// SHIFT+9 key "add last cargo selected by key 9"
	// If iSelectedCargo=-1 (default) add to the first free slot found
	if(key==OAPI_KEY_9&&KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		if(hUcgo.ScnEditor_AddLastSelectedCargoToSlot(iSelectedCargo)==TRUE)
		{
			strcpy(SendCargHudMessage(),"Cargo added to ship");
		}
		else
		{
			if(iSelectedCargo<0)
			{
				strcpy(SendCargHudMessage(),"Cargo not added (ship full or weight excess ?)");
			}
			else
			{
				strcpy(SendCargHudMessage(),"Cargo not added (slot full ship full or weight excess ?)");
			}
		}
		return 1;
	}
	// "C" grapple cargo. If iSelectedCargo=-1 (default) add to the first free slot found
	if(key==OAPI_KEY_C&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		int ReturnedCode=hUcgo.GrappleOneCargo(iSelectedCargo);
		// for return code list see function "GrappleOneCargo" in the header
		switch(ReturnedCode)
		{
		case 1:
			strcpy(SendCargHudMessage(),"Cargo grappled");
			break;
		case 0:
			strcpy(SendCargHudMessage(),"No cargo in range");
			break;
		case -1:
			strcpy(SendCargHudMessage(),"cargo exceed maximum mass");
			break;
		case -2:
			strcpy(SendCargHudMessage(),"bad config, mesh not found or slot not declared");
			break;
		case -3:
			strcpy(SendCargHudMessage(),"Can't grapple cargo, slot not empty");
			break;
		case -4:
			strcpy(SendCargHudMessage(),"Can't grapple cargo,doors closed ");
			break;
		case -5:
			strcpy(SendCargHudMessage(),"Can't grapple cargo,Ship full");
			break;
		default:
			strcpy(SendCargHudMessage(),"Misc error Unable to grapple cargo");
		}
		return 1;
	}
	// SHIFT+C release cargo. If iSelectedCargo=-1 (default) release the first free slot found
	if(key==OAPI_KEY_C&&KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		if(hUcgo.ReleaseOneCargo(iSelectedCargo)!=FALSE)
		{
			strcpy(SendCargHudMessage(),"Cargo released");
		}
		else
		{
			strcpy(SendCargHudMessage(),"Cargo not released (empty slot, no cargo aboard?)");
		}
		return 1;
	}
	// "8" show some info on cargo
	if(key==OAPI_KEY_8&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		sprintf(SendCargHudMessage(),"%i cargos aboard. "
		"Total cargos weight: %.0fkg",hUcgo.GetNbrCargoLoaded(),hUcgo.GetCargoTotalMass());
		return 1;

	}
	if(key==OAPI_KEY_E&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		// PERFORM THE EVA, first we get is name with "GetCrewNameBySlotNumber" then we perform EVA with "EvaCrewMember"
		int Returned=Crew.EvaCrewMember(Crew.GetCrewNameBySlotNumber(SelectedUmmuMember));
		// we provide feedback to user (You can display a message on panel or wathewer)
		// here below all the return code possible:
		switch(Returned)
		{
		case TRANSFER_TO_DOCKED_SHIP_OK:
			sprintf(SendHudMessage(),"Transfer to docked ship Ok - %s transfered",
			Crew.GetLastEvaedCrewName());SelectedUmmuMember=0;
			break;
		case EVA_OK:
			sprintf(SendHudMessage(),"EVA OK - %s left the ship",
			Crew.GetLastEvaedCrewName());SelectedUmmuMember=0;
			break;
		case ERROR_NO_ONE_ON_BOARD:
			strcpy(SendHudMessage(),"Error, no one on board, unable to EVA");
			break;
		case ERROR_AIRLOCK_CLOSED:
			strcpy(SendHudMessage(),"Error, airlock is closed, unable to EVA");
			break;
		case ERROR_DOCKED_SHIP_HAVE_AIRLOCK_CLOSED:
			strcpy(SendHudMessage(),"Error, docked ship's airlock is closed, unable to transfer");
			break;
		case ERROR_DOCKED_SHIP_IS_FULL:
			strcpy(SendHudMessage(),"Error, docked ship is already full transfer failed");
			break;
		case ERROR_CREW_MEMBER_NOT_FOUND:
			strcpy(SendHudMessage(),"Error, no crew by this name in ship");
			break;
		case ERROR_DOCKEDSHIP_DONOT_USE_UMMU:
			strcpy(SendHudMessage(),"Error, docked ship do not use UMmu 2.0, ask author to add it");
			break;
		case ERROR_MISC_ERROR_EVAFAILED:
			strcpy(SendHudMessage(),"Misc error with UMMU install it again");
			break;
		}
		return TRUE;
	}
if(key==OAPI_KEY_1&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		// we test there is someone aboard
		if(Crew.GetCrewTotalNumber()==0)
		{
			strcpy(SendHudMessage(),"Sorry no one aboard unable to select");	
			return 1;
		}

		// we test that we select existing member
		if(SelectedUmmuMember<Crew.GetCrewTotalNumber()-1)
			SelectedUmmuMember++;
		char * Name=Crew.GetCrewNameBySlotNumber(SelectedUmmuMember);
		sprintf(SendHudMessage(),"Slot %i  %s \"%s\" aged %i Selected for EVA or Transfer, please press \"E\" to EVA",
		SelectedUmmuMember,Crew.GetCrewMiscIdBySlotNumber(SelectedUmmuMember),
		Name,Crew.GetCrewAgeBySlotNumber(SelectedUmmuMember));
		return 1;
	}

	//---------------------------------------------------------------------------
	// Ummu Key "2" Select previous member This is just internal to the demo
	// you may do your own selection system by panel button
	if(key==OAPI_KEY_2&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		// we test there is someone aboard
		if(Crew.GetCrewTotalNumber()==0)
		{
			strcpy(SendHudMessage(),"Sorry no one aboard unable to select");	
			return 1;
		}
		if(SelectedUmmuMember>0)
			SelectedUmmuMember--;
		char * Name=Crew.GetCrewNameBySlotNumber(SelectedUmmuMember);
		sprintf(SendHudMessage(),"Slot %i %s \"%s\" aged %i Selected for EVA or Transfer"
			", please press \"E\" to EVA",SelectedUmmuMember,
			Crew.GetCrewMiscIdBySlotNumber(SelectedUmmuMember),Name,
			Crew.GetCrewAgeBySlotNumber(SelectedUmmuMember));
		return 1;
	}
	if(key==OAPI_KEY_D&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{		
	//
		Crew.SetAirlockDoorState(!Crew.GetAirlockDoorState());
		// display state
		if (doorselected==0)
			{RevertDOOR1 ();
		if(Crew.GetAirlockDoorState()==TRUE)
			strcpy(SendHudMessage(),"Left Front Airlock is now open");	
		else
			strcpy(SendHudMessage(),"Left Airlock is now closed");
		}

	
if (doorselected==1)
{RevertDOOR2();
if(Crew.GetAirlockDoorState()==TRUE)
			strcpy(SendHudMessage(),"Right Front Airlock is now open");	
		else
			strcpy(SendHudMessage(),"Right Front Airlock is now closed");

	}

if (doorselected==2)
{RevertDOOR3();
if(Crew.GetAirlockDoorState()==TRUE)
			strcpy(SendHudMessage(),"Left Rear Airlock is now open");	
		else
			strcpy(SendHudMessage(),"Left Rear Airlock is now closed");

	}
if (doorselected==3)
{RevertDOOR4();
if(Crew.GetAirlockDoorState()==TRUE)
			strcpy(SendHudMessage(),"Right Rear Airlock is now open");	
		else
			strcpy(SendHudMessage(),"Right Rear Airlock is now closed");

	}

	}

	//---------------------------------------------------------------------------
	// Get some infos Name of ship and total soul aboard
	if(key==OAPI_KEY_S)
	{
		sprintf(SendHudMessage(),"%i souls aboard ship %s, %i seats available",
			Crew.GetCrewTotalNumber(),GetName(),6-Crew.GetCrewTotalNumber());
		return 1;
	}

	//---------------------------------------------------------------------------
	// ADD some Fun, Eject the guy, No check of all return code here to keep listing small and clear.
	// Notice eject function doesn't check airlock state at all.
	// GOOD IDEA: Get the Object's handle after ejection with function "GetObjHandleOfLastEVACrew"
	// and add to it one very small tank, thruster and smoke, then fire thruster (see pilot ejection of DGIV)
	// BAD IDEA: Not testing the handle returned by "GetObjHandleOfLastEVACrew" before using may
	// cause a CTD if by any bad luck the pointer is invalid (handle==NULL)
	if(key==OAPI_KEY_ESCAPE&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		if(Crew.EjectCrewMember(Crew.GetCrewNameBySlotNumber(SelectedUmmuMember))==EVA_OK)
			sprintf(SendHudMessage(),"%s EJECTED",Crew.GetLastEvaedCrewName());
		SelectedUmmuMember=0;
		return 1;
	}

	//---------------------------------------------------------------------------
	// Use a different Mesh (type "C" then EVA someone)
	// better idea is to use the new UMMU Id definition
	// look readme.txt in folder "config/UMMUIdConfig"
	if(key==OAPI_KEY_C)
	{
		Crew.SetAlternateMeshToUseForEVASpacesuit("mmu");	// the stock mmu of orbiter located in "meshes/mmu.msh"
		strcpy(SendHudMessage(),"Mesh changed");
		return 1;
	}

	// THIS IS FOR ADDING CREW SEE PDF doc "Allow user to add crew to your ship 
	// without scenery editor"
	if(key==OAPI_KEY_M&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
	{
		AddUMmuToVessel(TRUE);
	}
//---------------------------------------------------------------------------
	        //sprintf(SendHudMessage(),"Active dock number changed to: %i",iActiveDockNumber);

 // change active dock
    if(key==OAPI_KEY_0)
    {
        if(iActiveDockNumber>0)
        iActiveDockNumber--;
     //   sprintf(SendHudMessage(),"Active dock number changed to: %i",iActiveDockNumber);
		if(iActiveDockNumber==0) sprintf(SendHudMessage(),"Left Front Airlock Selected");
		if(iActiveDockNumber==1) sprintf(SendHudMessage(),"Right Front Airlock Selected");
				if(iActiveDockNumber==2) sprintf(SendHudMessage(),"Left Rear Airlock Selected");
		if(iActiveDockNumber==3) sprintf(SendHudMessage(),"Right Rear Airlock Selected");


        SetUMMUAirlockPos();
        return 1;
    }
    //---------------------------------------------------------------------------
    // change active dock
    if(key==OAPI_KEY_MINUS)
    {
        if(iActiveDockNumber<3)
        iActiveDockNumber++;
 //   sprintf(SendHudMessage(),"Active dock number changed to: %i",iActiveDockNumber);
		if(iActiveDockNumber==0) sprintf(SendHudMessage(),"Left Front Airlock Selected");
		if(iActiveDockNumber==1) sprintf(SendHudMessage(),"Right Front Airlock Selected");
		if(iActiveDockNumber==2) sprintf(SendHudMessage(),"Left Rear Airlock Selected");
		if(iActiveDockNumber==3) sprintf(SendHudMessage(),"Right Rear Airlock Selected");
		

        SetUMMUAirlockPos();
        return 1;
    }

    //---------------------------------------------------------------------------
    

if(key==OAPI_KEY_V)
{

    CAM = CAM + 1;
    if(CAM > 4) CAM = 0;
	
        SelectCockpitView(CAM);
        return 1;
}  



if(key==OAPI_KEY_K)
{
	if(IGNITION_check == NO_START)	{IGNITION_check=YES_START;
	PlayVesselWave(BELL222ID,BELL222Start,NOLOOP,225);
	SetThrusterLevel(th_hover[0],0.1);
	}// started
	else	
		if(IGNITION_check == YES_START)	IGNITION_check=NO_START;

	
      return 1;
}



if(key==OAPI_KEY_G)
{
	//LoadAndPlay("warning_low_fuel.wav");
	//PlayVesselWave(BELL222Gear,NOLOOP,255); 
				PlayVesselWave(BELL222ID,BELL222Gear,NOLOOP,225);		

	//RequestLoad3DWaveMono(BELL222ID,BELL222Gear,"BELL222Gear.wav",INTERNAL_ONLY,&_V(-1,2,10));	
//	RevertGEARCOVER();

RevertGEAR();
 return 1;
}







	
return 0;
}

// ====================================================================
// clbkVisualCreated used to display UMMU initialisation message 
// because oapiDebugString() doesn't work in clbkSetClassCap
// ====================================================================
void BELL222::clbkVisualCreated (VISHANDLE vis, int refcount)
{   
	MainExternalMeshVisual = GetMesh(vis,0);
			hUcgo.SetUcgoVisual(vis);	// must be called in clbkVisualCreated.

	
}
// ==============================================================
// Visual destroyed
// ==============================================================
void BELL222::clbkVisualDestroyed (VISHANDLE vis, int refcount)
{
	MainExternalMeshVisual = 0;	
}



// ========================================================================
// clbkLoadState function of Orbiter - Save scenario when user exit Orbiter 
// ========================================================================

//------------------------------------------------------------------------------------------------------------------
// This below is not mandatory for UMmu to run.
//------------------------------------------------------------------------------------------------------------------

// ==========================================================
// USING TEXT INTERFACE FOR CREW MANAGMENT (not a good idea)
//
// This is the custom functions that send oapiDebugString() Message on screen
// it simply avoid that the message is sent if our ship don't have the focus
// and ensure that message will be reminded when we focus back on ship
// the Orbiter function below clbkFocusChanged is used to erase message when
// we lost focus.
// It's a bad idea to do an UMmu user interface only by using Debug screen message 
// but if you can't do better you may use this system.
///////////////////////////////////////////////////////////////////////////////////////////

// --------------------------------------------------------------
// Orbiter's HUD callback
// used to display UMMU's message see PDF doc:
// "Example of feedback method by HUD Display"
// --------------------------------------------------------------
void BELL222::clbkDrawHUD (int mode, const HUDPAINTSPEC *hps, HDC hDC)
{
	VESSEL2::clbkDrawHUD (mode, hps, hDC);

	// UCGO display messages
	if(dCargHudMessageDelay>0)
	{
		TextOut (hDC,5,hps->H/60*15,cCargoHudDisplay,strlen(cCargoHudDisplay));
		dCargHudMessageDelay-=oapiGetSimStep();
		if(dCargHudMessageDelay<0)
			dCargHudMessageDelay=0;
	}
	if(dHudMessageDelay>0)
	{
		TextOut (hDC,5,hps->H/60*20,cUmmuHudDisplay,strlen(cUmmuHudDisplay));
		dHudMessageDelay-=oapiGetSimStep();
		if(dHudMessageDelay<0)
			dHudMessageDelay=0;
	}
}
void BELL222::clbkSaveState(FILEHANDLE scn)
{
char cbuf[256];
	



	// ORBITER, default vessel parameters
	SaveDefaultState (scn);
	hUcgo.SaveCargoToScenario(scn);	


	 sprintf (cbuf, "%d %0.4f", GEAR_status, GEAR_proc);
		oapiWriteScenario_string (scn, "GEAR", cbuf);

			 sprintf (cbuf, "%d %0.4f", DOOR1_status, DOOR1_proc);
		oapiWriteScenario_string (scn, "DOOR1", cbuf);

		 
 
		sprintf (cbuf, "%d ", IGNITION_check);
		oapiWriteScenario_string (scn, "IGNITION", cbuf);
		
		sprintf (cbuf, "%d %0.4f", DOOR2_status, DOOR2_proc);
		oapiWriteScenario_string (scn, "DOOR2", cbuf);


 sprintf (cbuf, "%0.4f", ROTORD_SPEED);
		oapiWriteScenario_string (scn, "HOVER", cbuf);


		 sprintf (cbuf, "%d %0.4f", DOOR3_status, DOOR3_proc);
		oapiWriteScenario_string (scn, "DOOR3", cbuf);

		sprintf (cbuf, "%d %0.4f", DOOR4_status, DOOR4_proc);
		oapiWriteScenario_string (scn, "DOOR4", cbuf);

	// UMmu, this will save all our members of crew in scenario
	// as airlock state depend of your ship (you may have a real animated airlock)
	// it's your responsabilites to save and reload UMmu's airlock state.
	Crew.SaveAllMembersInOrbiterScenarios(scn);
}
void BELL222::clbkLoadStateEx (FILEHANDLE scn, void *status)
{
	char *line;
	while (oapiReadScenario_nextline (scn, line)) 
	{
		// call this method to let PayloadManager to load its internal parameters

		// UMMU, Load all saved member from scenario. 
		// Return TRUE when a "UMMUCREW" line is encountered 
		// FALSE when it must pass this line to you or default parser
		if(Crew.LoadAllMembersFromOrbiterScenario(line)==TRUE)
			continue;
		if(hUcgo.LoadCargoFromScenario(line)==TRUE) // UCGO load cargo 
			continue;	


	      if (!_strnicmp (line, "GEAR", 4)) {
   sscanf (line+4, "%d%lf", &GEAR_status, &GEAR_proc);
			}

 if (!_strnicmp (line, "DOOR1", 5)) {
   sscanf (line+5, "%d%lf", &DOOR1_status, &DOOR1_proc);
			}

		  if (!_strnicmp (line, "DOOR2", 5)) {
   sscanf (line+5, "%d%lf", &DOOR2_status, &DOOR2_proc);
			}
	      
		     
			  
	if (!_strnicmp (line, "DOOR3", 5)) {
   sscanf (line+5, "%d%lf", &DOOR3_status, &DOOR3_proc);
			}
 
if (!_strnicmp (line, "DOOR4", 5)) {
   sscanf (line+5, "%d%lf", &DOOR4_status, &DOOR4_proc);
			}


 if (!_strnicmp (line, "IGNITION", 8)) {
   sscanf (line+8, "%d", &IGNITION_check);
		}
 if (!_strnicmp (line, "HOVER", 5)) {
 sscanf (line+5, "%lf",  &ROTORD_SPEED);
		}

		// ORBITER, unrecognised option - pass to Orbiter's generic parser
	
		        
		// ORBITER, unrecognised option - pass to Orbiter's generic parser
		ParseScenarioLineEx (line, status);
	}
SetAnimation (anim_GEAR, GEAR_proc);	
//SetAnimation (anim_DOOR2, DOOR2_proc);
//SetAnimation (anim_DOOR1, DOOR1_proc);		
//SetAnimation (anim_DOOR3, DOOR3_proc);		
//SetAnimation (anim_DOOR4, DOOR4_proc);		

SetAnimation (anim_ROTOR, ROTORD_proc);		
//SetAnimation (anim_ROTOR1, ROTOR_proc);		
SetAnimation (anim_ROTOR2, ROTORD_proc);		
SetAnimation (anim_ROTOR3, ROTORD_proc);		

			

//if (DOOR1_proc<.1)Crew.SetAirlockDoorState(TRUE);
//if (DOOR2_proc<.1)Crew.SetAirlockDoorState(TRUE);
//if (DOOR3_proc<.1)Crew.SetAirlockDoorState(TRUE);
//if (DOOR4_proc<.1)Crew.SetAirlockDoorState(TRUE);

	// as airlock state depend of your ship (you may have a real animated airlock)
	// it's your responsabilites to save and reload UMmu airlock state and set it accordingly
	// to your airlock. IE: call here "SetAirlockDoorState" TRUE of FALSE depend
	// of your animated airlock
}
bool UMmuCrewAddCallback(void *id, char *str, void *data)
{
	if(strlen(str)<2||strlen(str)>38)
		return false;
	char *cPtr=(char*)data;	if(*cPtr==2){*cPtr=3;strcpy(cPtr+2,str);}
	else if(*cPtr==4){*cPtr=5;strcpy(cPtr+42,str);}
	else if(*cPtr==6){*cPtr=7;strcpy(cPtr+82,str);}return true;
}
void BELL222::AddUMmuToVessel(BOOL bStartAdding)
{
	if(bStartAdding==FALSE&&cAddUMmuToVessel[0]==0)
		return;
	if(bStartAdding==TRUE){
		int salut=sizeof(cAddUMmuToVessel);
		memset(cAddUMmuToVessel,0,sizeof(cAddUMmuToVessel));
		cAddUMmuToVessel[0]=1;
	}
	else if(cAddUMmuToVessel[0]==1){
		cAddUMmuToVessel[0]=2;
		oapiOpenInputBox ("Enter new crew's name (or escape)",UMmuCrewAddCallback,0,30,(void*)cAddUMmuToVessel);
	}
	else if(cAddUMmuToVessel[0]==3){
		cAddUMmuToVessel[0]=4;
		oapiOpenInputBox ("Enter crew's age",UMmuCrewAddCallback,0,30,(void*)cAddUMmuToVessel);
	}
	else if(cAddUMmuToVessel[0]==5){
		cAddUMmuToVessel[0]=6;
		oapiOpenInputBox ("Enter function (Capt,Sec,Vip,Sci,Doc,Tech,Crew,Pax)",UMmuCrewAddCallback,0,30,(void*)cAddUMmuToVessel);
	}
	else if(cAddUMmuToVessel[0]==7){
		cAddUMmuToVessel[0]=0;
		int Age=max(5,min(100,atoi(&cAddUMmuToVessel[42])));
		if(Crew.AddCrewMember(&cAddUMmuToVessel[2],Age,70,70,&cAddUMmuToVessel[82])==TRUE){
			sprintf(SendHudMessage(),"Crew \"%s\" aged %i added to vessel",&cAddUMmuToVessel[2],Age);
		}
		else{
			strcpy(SendHudMessage(),"ERROR: Crew not added (vessel full?)");
		}
	}
}



void BELL222::RevertGEAR (void)
{
	GEAR_status = ((GEAR_status == GEAR_UP || GEAR_status == GEAR_RAISING) ?
		GEAR_LOWERING : GEAR_RAISING);
}
void BELL222::RevertDOOR2 (void)
{
	DOOR2_status = ((DOOR2_status == GEAR_UP || DOOR2_status == GEAR_RAISING) ?
		GEAR_LOWERING : GEAR_RAISING);
}
void BELL222::RevertDOOR1 (void)
{
	DOOR1_status = ((DOOR1_status == GEAR_UP || DOOR1_status == GEAR_RAISING) ?
		GEAR_LOWERING : GEAR_RAISING);
}
void BELL222::RevertDOOR3 (void)
{
	DOOR3_status = ((DOOR3_status == GEAR_UP || DOOR3_status == GEAR_RAISING) ?
		GEAR_LOWERING : GEAR_RAISING);
}
void BELL222::RevertDOOR4 (void)
{
	DOOR4_status = ((DOOR4_status == GEAR_UP || DOOR4_status == GEAR_RAISING) ?
		GEAR_LOWERING : GEAR_RAISING);
}

                              
          



bool BELL222::clbkLoadVC(int id)
{
 VCHUDSPEC hud;
 VCMFDSPEC mfd;
 
 //Virtual cockpit elements
 if((id>=0)&&(id<1)){
  if(id==0){
   SetCameraDefaultDirection(_V(0,0,1));
   SetCameraOffset(_V(.48,-.4,5.1));
   SetCameraShiftRange(_V(0,0,0.1),_V(-0.2,0,0),_V(0.2,0,0));
   oapiVCSetNeighbours(-1,-1,-1,-1);

   hud.nmesh=1;
   hud.ngroup=38;
   hud.hudcnt=_V(0, 0, 0);
   hud.size=.25;
   oapiVCRegisterHUD(&hud);
   mfd.ngroup=37;
   mfd.nmesh=1;
   oapiVCRegisterMFD(0,&mfd);
   mfd.ngroup=39;
   mfd.nmesh=1;
   oapiVCRegisterMFD(1,&mfd);
  }
 }
 return 1;
}
